#
# spec file for package simple-ccsm
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _rev    c7b6d3ccd61a65e81125ddb8627d55f6
Name:           simple-ccsm
Version:        0.8.16
Release:        1.1
Summary:        Simple settings manager for Compiz
License:        GPL-2.0-or-later
Group:          System/X11/Utilities
URL:            https://gitlab.com/compiz/simple-ccsm
Source:         https://gitlab.com/compiz/simple-ccsm/uploads/%{_rev}/%{name}-%{version}.tar.xz
BuildRequires:  compiz < 0.9
BuildRequires:  fdupes
BuildRequires:  gobject-introspection-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  libcompizconfig < 0.9
BuildRequires:  python3-devel
BuildRequires:  update-desktop-files
Requires:       compiz < 0.9
Requires:       compiz-plugins < 0.9
Requires:       compiz-plugins-main < 0.9
Requires:       python3-cairo
Requires:       python3-ccm < 0.9
Requires:       python3-ccm >= 0.8.12
Requires:       python3-compizconfig < 0.9
Requires:       python3-gobject
Requires:       python3-gobject-cairo
Recommends:     %{name}-lang
Recommends:     compiz-plugins-extra < 0.9
# simple-ccsm-kde was last used in openSUSE 11.3.
Provides:       %{name}-kde = %{version}
Obsoletes:      %{name}-kde < %{version}
Provides:       ccsm = 0.8
BuildArch:      noarch
%if 0%{?suse_version} >= 1500 || 0%{?sle_version} >= 120200
Requires:       python3-gobject-Gdk
%endif

%description
Compiz settings manager focused on simplicity for an end-user.

%lang_package

%prep
%setup -q

%build
python3 setup.py build \
  --prefix=%{_prefix}    \
  --enableDesktopEffects

%install
python3 setup.py install \
  --root=%{buildroot} \
  --prefix=%{_prefix}

mv %{buildroot}%{_datadir}/{metainfo,appdata}/
%fdupes %{buildroot}%{_datadir}/
%suse_update_desktop_file -N "Desktop Effects" %{name}
%find_lang simple-ccsm

%if 0%{?suse_version} < 1500
%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%endif

%files
%license COPYING
%doc AUTHORS NEWS README.md
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{python3_sitelib}/simple_ccsm-*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml

%files lang -f %{name}.lang

%changelog
* Mon Nov 12 2018 sor.alexei@meowr.ru
- Update to version 0.8.16:
  * Fix Compiz checking.
  * Fix some GTK+ deprecations.
  * Use GApplication for command line option parsing.
  * Prevent multiple instances using GtkApplication.
  * setup.py: Exit 1 for invalid arguments.
  * Update translations.
* Thu Apr 20 2017 sor.alexei@meowr.ru
- Update to version 0.8.14.1:
  * Fix Compiz checking on Python3.
  * Silence a RSVG API version startup warning.
* Tue Apr 18 2017 sor.alexei@meowr.ru
- Update to version 0.8.14:
  * Fixes for Python3.
  * Update translations.
- Switch to Python3.
* Wed May  4 2016 sor.alexei@meowr.ru
- Add missing python-gobject-cairo and python-gobject-Gdk
  dependencies.
* Wed Mar 23 2016 sor.alexei@meowr.ru
- Update to 0.8.12:
  * Target Compiz 0.8.x, not Compiz 0.9.x.
  * Replace PyGObject2, PyGtk2 dependency with PyGObject3.
    New minimal Gtk requirements are: either Gtk 2.24.10+ or
    Gtk 3.2+, and now simple-ccsm needs CCSM 0.8.12 to work (older
    versions couldn't work with CCSM 0.8.12 and higher).
  * Add support for MATE.
  * Drop KDE4 support hacks but now do show the desktop entry in KDE.
  * Fix selection of the Default profile on non-English systems
    resulting in creation of the new profile.
  * Remove compiz-manager requirement and support.
  * Don't crash when cubeaddon is not installed.
  * Remove the Help button pressing which did nothing.
- Remove simple-ccsm-compiz08.patch, simple-ccsm-mate-compat.patch:
  merged upstream.
- Cleanup dependencies.
* Thu Sep 24 2015 sor.alexei@meowr.ru
- Split simple-ccsm-lang package.
- Obsolete simple-ccsm-kde.
- Remove simple-ccsm-default-plugins_herbster0815.patch.
- Add license file to package.
- Update icon cache in postinst.
- Add simple-ccsm-mate-compat.patch and regexp replacing gnomecompat
  with matecompat in profiles: adapt for MATE.
- Add simple-ccsm-compiz08.patch and regexp replacing 0.9.x plugins:
  adapt for Compiz 0.8.x.
- Remove update.sh: this is a released version.
- Spec cleanup.
* Thu May 31 2012 ku.b@gmx.de
- correct license format
* Thu Apr 28 2011 robertherb@arcor.de
- Update to version 0.8.8
- adapt to 0.8.8
* Thu May 27 2010 dimstar@opensuse.org
- Require the new python-ccm backend package instead of the
  full compizconfig-settings-manager with gui.
* Mon Feb 22 2010 dimstar@opensuse.org
- Change name back to 'Desktop Effects' in the menu, bnc#581548.
* Mon Nov 16 2009 dimstar@opensuse.org
- Require compiz-plugins-main instead of compiz-fusion-plugins-main
* Fri Nov 13 2009 dimstar@opensuse.org
- Update to version 0.8.4:
  + Fix KDE autostart
  + Don't show simple-ccsm in kde.
  + Enable desktop integration and gnomecompatibility on startup
- Disable simple-ccsm-desktop.patch
- Disable simple-ccsm-kde-enable.patch, upstreamed
* Sun Oct 11 2009 dimstar@opensuse.org
- Fix spelling in simple-ccsm-cm-dry.patch. Pointed out by
  upstream.
* Fri Aug 21 2009 dimstar@opensuse.org
- Define new python macros on openSUSE <= 11.1
* Sun Aug  9 2009 coolo@suse.com
- use new python macros
* Tue Jan 27 2009 davidr@novell.com
- Include dmx plugin in all profiles (bnc#469843)
* Tue Jan 27 2009 rodrigo@novell.com
- Increment rollback timeout to 30 secs (bnc#467642)
* Fri Nov 28 2008 rodrigo@novell.com
- Use GtkMessageDialog's for the question/warning dialogs, to get
  nice icons
- Fix some issues with the timeout dialog callbacks
* Thu Nov 27 2008 rodrigo@novell.com
- Improve rollback mechanism with a timeout'ed dialog, which
  restores previous settings if something goes wrong
* Fri Nov 21 2008 rodrigo@novell.com
- If running compiz fails, disable desktop effects (bnc#407729)
* Fri Nov 14 2008 rodrigo@novell.com
- Review and merge changes from X11:Compiz
* Fri Nov 14 2008 cyberorg@opensuse.org
- fixed simple-ccsm-explicitly-disable-compiz.patch
  from Brandon Philips <bphilips@novell.com> (bnc#442138)
* Fri Nov  7 2008 rodrigo@novell.com
- Add simple-ccsm-cm-dry.patch to use os.system for the 'CM_DRY=yes
  compiz-manager' command (bnc@407729) and deal correctly with
  exceptions when executing kwriteconfig (bnc#441823)
* Tue Nov  4 2008 rodrigo@novell.com
- Review and merge changes from X11:Compiz
* Tue Nov  4 2008 cyberorg@opensuse.org
- Add NotShowIn=KDE; bnc #432330
* Mon Oct 27 2008 rodrigo@novell.com
- Removed explicit library Requires:
- Add simple-ccsm-explicitly-disable-compiz.patch to create a
  disable-compiz file in ~/.config/compiz to make sure compiz is
  not started in gnome-session (bnc#436873)
* Mon Oct 13 2008 rodrigo@novell.com
- Review and merge changes from X11:Compiz
* Sun Oct 12 2008 cyberorg@opensuse.org
- simple-ccsm.desktop patch for better menu integration
* Tue Oct  7 2008 rodrigo@novell.com
- Review and merge changes from X11:Compiz
* Tue Oct  7 2008 cyberorg@opensuse.org
- Add wm plugin to all profiles
- remove crashy imjpeg plugin from profiles bnc #432313 workaround
* Mon Oct  6 2008 rodrigo@novell.com
- Review and merge changes from X11:Compiz
* Sat Oct  4 2008 cyberorg@opensuse.org
- include glx plugin in other profiles bnc #432301
* Mon Sep 29 2008 rodrigo@novell.com
- Review and merge changes from X11:Compiz
* Fri Sep 26 2008 cyberorg@opensuse.org
- Fix enabling compiz on kde, simple-ccsm-kde-enable.patch
* Mon Sep 22 2008 cyberorg@opensuse.org
- Fix profile handling when desktop effects are not enabled
* Wed Sep 17 2008 cyberorg@opensuse.org
- Release 0.7.8
- simple-ccsm-compiz-manager-cmd.diff add --replace
* Mon Sep 15 2008 cyberorg@opensuse.org
- l10n updates
- Reduce startup time
- Add support for the extensible animation plugin
* Tue Jul  1 2008 mhopf@suse.de
- Updated from buildservice.
* Sat May 31 2008 cyberorg@opensuse.org
- Removed hard-dependency on some plugins (e.g. animation),
  simple-ccsm will now be able to start without them
- New profiles: Minimal, Medium, Advanced and Ultimate
- Show which accessibility features (zoom, colorfilter) are enabled
- Cube effects (deformation, transparency, reflection) are now configurable
- Window focus animation is now configurable
* Wed May 21 2008 cyberorg@opensuse.org
- Fix typo in switch patch
* Wed May 21 2008 cyberorg@opensuse.org
- add --replace to compiz command
* Wed May 21 2008 cyberorg@opensuse.org
- enable compiz in kde kcontrol too
* Tue May 20 2008 rodrigo@suse.de
- Updated simple-ccsm-enable-desktop-effects.patch to use --replace
  when starting compiz now that it's removed in compiz-manager
* Mon May 12 2008 rodrigo@suse.de
- Updated simple-ccsm-enable-desktop-effects.patch to use Python
  API instead of spawning shell commands
* Fri May  9 2008 rodrigo@suse.de
- Changed True to true for .desktop field values
* Wed May  7 2008 rodrigo@suse.de
- Update simple-ccsm-enable-desktop-effects.patch to add startup
  notification and add a test run before really activating compiz,
  warning the user if hardware is not supported (bnc#386836)
* Mon May  5 2008 rodrigo@suse.de
- Add simple-ccsm-backports.patch that fixes many GUI glitches
  (bnc#383345)
- Updated simple-ccsm-enable-desktop-effects.patch to create/remove
  a ~/.config/compiz/enable-compiz file so that gnome-wm knows what
  WM is the preferred one (bnc#381675)
* Mon Apr 28 2008 rodrigo@suse.de
- Added missing dependency on compiz-fusion-plugins-main and
  compizconfig-settings-manager (bnc#382509)
* Tue Apr 15 2008 rodrigo@suse.de
- Update simple-ccsm-enable-desktop-effects.patch to make simple-ccsm
  now be the 'Desktop Effects' icon in control-center
- Added compiz-manager to Requires:
* Fri Apr 11 2008 rodrigo@suse.de
- Update to version 0.7.4:
  * Added expo plugin to effects page
  * Added widget to configure global edge settings
  * Added ‘mag’ plugin as ‘area zoom’ to zoom page
- Added simple-ccsm-enable-desktop-effects.patch to allow activation
  of compiz and its configuration all from the same place
* Fri Mar  7 2008 cyberorg@opensuse.org
- 0.7.2 development release
